bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 30. Aventiure
___________________________________________________ #### Auentvre wie die kvnige mit ir rechen slafen <giengen> #### vn– wie in do geschach
| ### <Der> tac der het nv ende vn– nahet in div naht ### den wegemvden degenen ir sorgens an vaht ### die herren solden rowen vn– an ir bette gan ### daz bereite Hagene ez wart [66r]in schiere chvnt getan ### Gvnther sprach zem wirte got laze ivch mit frevden lebn ### wir wellen varn slafen ir svlt vns vrlovp gebn ### als ir vns gebietet wir chomen morgen frvo ### er schiet von sinen gesten vil harte minneklichen do
###### 1864 | ### Dringen allenthalben die geste man do sach ### Volker der chvene zv den Hvnen sprach ### wie getvrret ir den rechen vf die fvze gan ### vn– welt irs niht ivch mazen so wirt iv leide getan
###### 1865 | ### So slah ich eteslichem so swæren gigenslac ### hat er getriwen iemen daz erz beweinen mac ### wan wichet ir vns rechen ia dvnchet ez mich gvot ### ez heizent alle degene vn– sint geliche niht gemvot
| ### Do der videlære so zornechliche sprach ### Hagen der chvene vber ahsel sach ### er saget iv rætet rehte der chvne spileman ### ir Chriemh' degene ir svlt zen herbergen gan
###### 1867 | ### Des ir da habet willen ich wæn ez iemen tvo ### welt ir sin beginnen so chomt vns morgen frvo ### vn– lat vns wegemvden hint haben gemach ### ia wæn ez von heleden mit solchem willen ie geschach
###### 1868 | ### Do brahte man die geste in einen witen sal ### dar inne si sit namen den totlichen val ### da fvnden si gerihtet vil manigiv bette breit ### in riet div kuneginne div aller groezisten leit
###### 1869 | ### Vil manigen kvlter spæhe von Arraz man da sach ### von vil liehten pfellen vn– manige bette dach ### von arabischen siden so si beste chvnden sin ### ovch lage in vf den enden von golde herlicher schin
###### 1870 | ### Div dechelachen hærmin vil menegiv man da sach ### vn– ovch von swarcem zobele dar vnder si ir gemach ### des nahtes solden schaffen vnz an den liehten tac ### ein kunec mit sinen frivnden nie so herlich gelach
| ### Owe der nahtselde sprach <Giselher> daz kint ### vn– owe miner frivnde die mit mir chomen sint ### swie et ez min swester mir gvetlich erbot ### ir fverhte daz wir mvzen von ir schulden ligen tot
###### 1872 | ### Nv lazet iwer sorgen sprach Hagen der degen ### ich wil der schiltwache noch hinte selbe pflegen ### ich behvete ivch wol mit triwen vnz vns chvmt der tac ### daz wizzet snelle degene so genese swer der mac
###### 1873 | ### Do nigen si im alle vn– sagten im des danc ### si giengen zvo den betten div wile was niht lanc ### daz sich engestet heten die ellenden man ### Hagene der starche sich do wafen began
###### 1874 | ### Do sprach der videlære Volker der degen ### versmahtez iv niht Hagene so wolde ich mit iv pflegen ### der schiltwache hinte vnze morgen frvo ### der helt vil minnekliche danchte Volkere dvo
| ### Nv lone iv got von himele vil edel Volker ### zallen minen sorgen sone gert ich niemens mer ### niwan ivch aleine swa ich hete [66v]not ### ich sol ez wol verdienen mich enwendes der tot
###### 1876 | ### Do garten si sich beide in liehtez ir gewant ### do nam ir ietewedere den schilt an sine hant ### vn– giengen vz dem hvse fvr die tvr do stan ### do hvten si der degene daz was mit triwen getan
###### 1877 | ### Volker der vil snelle zv des sales want ### sinen schilt den gvten leinte von der hant ### do gie er hin widere die videln er genam ### do dienter sinen frivnden als ez dem degene gezam
###### 1878 | ### Vnder <die> tvr des hvses saz er vf den stein ### chvner videlære div svnne nie beschein ### do im der seiten doenen so svozlich erchlanch ### die stolzen ellenden sagten im des grozen danc
###### 1879 | ### Do chlvngen sine seiten daz al daz hvos erdoz ### sin ellen zv der fvoge div beide warn groz ### senfter vn– svezer videln er began ### do enswebter an dem bette vil manigen sorgenden man
###### 1880 | ### Do si wol entslafen waren <vnde> er daz ervant ### do nam der degene widere den schilt an sine hant ### do gie er vz dem hvose fvr die tvre stan ### vn– hvote siner frivnde vor den Chriemh' man
| ### Nach dem ersten slafe ich wæn ez e geschach ### Volker der vil chvene einen helm schinen sach ### verre vz einer vinster die <Chriemhilde> man ### wolden an den gesten schaden gerne han getan
###### 1882 | ### Ê Chriemhilt dise rechen hete dan gesant ### si sprach ob irs also vindet dvrch got so sit gemant ### daz ir da slahet niemen wan den einen man ### den vngetriwen Hagenen die andern svlt ir lebn lan
###### 1883 | ### Do sprach der videlære nv seht her Hagene ### iane zimt mir diz mære niht ze dagene ### ia sih ich mit gewæfen dort her lvte gan ### als ich mich versinne ich wæn si wellent vns bestan
###### 1884 | ### Nv swiget sprach do Hagene lats vns her naher baz ### e si <vn> werden innen so wirt hie helme vaz ### mit swerten verrvcket von der minen hant ### si werdent hint ir frowen hin wider vbele gesant
| ### Ein der Hvnen rechen vil schiere daz gesach ### daz div tivre was behvetet wie balde er do sprach ### des wir da heten willen iane mag es niht engan ### ich sihe den videlære an der schiltwache stan
###### 1886 | ### Der treit vf sime hovbte einen helm glanz ### lvotter vn– herte veste vn– ganz ### ovch lohent sine ringe sam daz fivre tvot ### bi im stet ovch Hagene des sint die geste wol behvot
###### 1887 | ### Zehant si widercherten do Volker daz ersach ### zv sime hergesellen er zorneklichen sprach ### lat mich zv den rechen von dem hvose gan ### ich wil vragen der mære der frovn Chriemh' man
###### 1888 | ### Nein durch mine liebe sprach Hagene der degen ### welt ir deheines strites mit den helden pflegen ### so bestent si ivch mit swerten [67r]vn– bringent ivch in not ### so mvese ich iv helfen wêrz aller miner mage tot
###### 1889 | ### So wir danne beide komen in den strit ### zwene oder viere in einer kurzen zit ### die sprvngen zv dem hvose vn– tæten vns div leit ### an den slafenden div nimmer wrden verkleit
| ### Do sprach aber Volker so lat doch daz geschehn ### daz wir si innen bringen daz ich si habe gesehn ### daz des niht haben lovgen die Chriemh' man ### daz si vil mortliche gerne heten getan
###### 1891 | ### Do sprach der videlære den Hvnen vaste nach ### wie get ir svs gewafent war ist iv so gach ### welt ir schaden riten ir Chriemh' man ### dar svlt ir mih ze helfe vn– minen hergesellen han
###### 1892 | ### Des antwrte im niemen zornic was sin mvot ### pfi ir zagen boese sprach der degen gvot ### wolt ir slafende vns ermordet han ### daz ist so gvoten degenen her vil selten noch getan
###### 1893 | ### Do wart der kuniginne rehte daz geseit ### daz ir boten niht enwrben von schulden was ir leit ### do fvogte siz sit anders vil grimmech was ir mvot ### des mvsen sit engelten degene chvene vnde <GvoT>

<<< Übersicht <<< vorige Seite nächste Seite >>>